@@ -441,3 +441,10 @@ class DICOM_interface(Abstract_IO):
         # Save segmentation to disk
         pred_file = str(index) + ".nii.gz"
         nib.save(nifti, os.path.join(output_path, pred_file))
+
+    #---------------------------------------------#
+    #           check_file_termination            #
+    #---------------------------------------------#
+    @staticmethod
+    def check_file_termination(termination):
+        return termination in [".dcm"]
\ No newline at end of file
